Welcome to soap's documentation!
======================================

SOAP is a fast algorithm developed to search for coninuous sources of gravitational waves. However, has uses in searching for any long duration weak signal.

.. image:: https://git.ligo.org/joseph.bayley/soapcw/-/raw/master/pipeline/images/vitmap_ex.png

For more information on the search see the publications here:

Publications
--------
* Methods paper: https://journals.aps.org/prd/abstract/10.1103/PhysRevD.100.023006
* CNN followup paper: https://journals.aps.org/prd/abstract/10.1103/PhysRevD.102.083024
* Parameter estimation paper: https://journals.aps.org/prd/abstract/10.1103/PhysRevD.106.083022 

Setup
===========
.. toctree::
    :maxdepth: 1

    readme
    installation

SOAP search
===========

.. toctree::
    :maxdepth: 2

    viterbialgorithm.ipynb
    transitionmatrix.ipynb
    bayesianlineaware.ipynb

Usage
=============

.. toctree::
    :maxdepth: 2
   
    usage/index
    cnn_usage/index
    neville_usage/index
    pipeline_usage/index



Info
=========

.. toctree::
    :maxdepth: 1 

    modules
    contributing
    authors
    history
   

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
